import { Divider } from 'antd';
import { useEffect, useMemo, useState } from 'react';
import styles from './index.less';

const TabsContent = (props) => {
  const {
    defaultActiveKey = '1',
    active: parentActive,
    center = true,
    small = false,
    spacing = 4,
    items = {},
    bold = true,
    onChange,
  } = props;
  const [active, setActive] = useState(parentActive || defaultActiveKey);
  const renderContent = useMemo(() => {
    return items.find((item) => item.key == active)?.children;
  }, [active, items]);

  useEffect(() => {
    if (parentActive) {
      setActive(parentActive);
    }
  }, [parentActive]);
  return (
    <div>
      <div
        className={`${styles.tabsTitle} ${small ? styles.small : ''}`}
        style={center ? { justifyContent: 'center' } : {}}
      >
        {items.map((item, index) => (
          <>
            <div
              key={item.key}
              style={{
                padding: `0 ${small ? (spacing - 1) / 10 : spacing / 10}rem`,
                fontWeight: `${bold ? 'bold' : 'normal'}`,
              }}
              className={`${styles.tabsItem} ${
                active == item.key ? styles.active : ''
              }`}
              onClick={() => {
                setActive(item.key);
                onChange(item.key);
              }}
            >
              {item.label}
            </div>
            {index !== items.length - 1 && (
              <Divider
                type="vertical"
                style={{
                  height: '0.5rem',
                  width: '0.015rem',
                  backgroundColor: '#BCBABA',
                }}
              />
            )}
          </>
        ))}
      </div>
      <div>{renderContent}</div>
    </div>
  );
};
export default TabsContent;
