import ThresholdDetail from '@/components/ThresholdDetail';
import ThresholdModal from '@/components/ThresholdDetail/ThresholdModal';
import { changeRecordStatus } from '@/services/eqSelfInspection';
import { UnityAction } from '@/utils/utils';
import { Table, message } from 'antd';
import { useState } from 'react';
import styles from '../PatrolReportDetail.less';
import ErrorHandleModal from './ErrorHandleModal';
import Empty from './Empty';

export default function DeviceTable(props) {
  const {
    onClickItem,
    data = {},
    items,
    userList,
    type,
  } = props;
  console.log(items);
  const [loading, setLoading] = useState(false);
  const [visible, setVisible] = useState(false);
  const [errVisible, setErrVisible] = useState(false);
  const [currentItem, setCurrentItem] = useState({});
  const isSensor = type == 'sensor';

  const onClickThreshold = (record) => {
    setCurrentItem(record);
    setVisible(true);
  };
  const onClickError = (record) => {
    setCurrentItem(record);
    setErrVisible(true);
  };
  const handleError = async (values) => {
    setLoading(true);
    let res = await changeRecordStatus({
      ...values,
      Id: currentItem.Id,
      DeviceCode: currentItem.DeviceCode,
      DeviceName: currentItem.DeviceName,
      RecordId: data.Id,
      RepairMan: values.RepairMan * 1,
    });
    setLoading(false);
    if (res) {
      message.success('操作成功');
      setErrVisible(false);
    }
  };
  const columns = [
    {
      title: '设备名称',
      width: '20%',
      dataIndex: 'DeviceName',
    },
    {
      title: '巡检项',
      key: 'TemplateItem.Name',
      dataIndex: ['TemplateItem', 'Name'],
    },
    // {
    //   title: '设备位号',
    //   width: '16%',
    //   dataIndex: 'DeviceCode',
    // },
    {
      title: '设定值范围',
      render: (record) => (
        <ThresholdDetail
          current={record.Value || 0}
          data={record || {}}
          // onClick={() => onClickThreshold(record)}
        />
      ),
    },
    {
      title: '状态',
      dataIndex: 'Status',
      width: '1.25rem',
      render: (Status) => {
        switch (Status) {
          case -1:
          case 0:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#12CEB3' }}
                ></i>
                正常
              </div>
            );
          case 1:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FE5850' }}
                ></i>
                异常
              </div>
            );
          case 2:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FFE26D' }}
                ></i>
                警告
              </div>
            );
        }
      },
    },
  ];
  const handleClickItem = (data) => {
    if (!isSensor) {
      onClickItem(`DeviceTable-${data.Id}`, {
        type: data.Status,
        deviceCode: data.DeviceCode,
      });
    } else {
      onClickItem(`DeviceTable-${data.Id}`, {
        // type: data.Status,
        deviceCode: data.DeviceCode,
        value: Number(data.Value || 0),
        threshold: data.JsonNumThreshold,
      });
      UnityAction.sendMsg('SinglePowerEnvironFromWeb', JSON.stringify(data));
    }
  };

  // useEffect(() => {
  //   console.log('温控', items);
  //   if (isSensor)
  //     UnityAction.sendMsg('PowerEnvironsFromWeb', JSON.stringify(items));
  // }, [items]);

  // if (!isSensor) {
  //   columns.push({
  //     title: '操作',
  //     render: (record) =>
  //       record.Status == 1 && (
  //         <a style={{ color: '#FE5850' }} onClick={() => onClickError(record)}>
  //           异常处理
  //         </a>
  //       ),
  //   });
  // }

  return (
    <div>
      <Table
        columns={columns}
        dataSource={items}
        rowKey="Id"
        locale={{
          emptyText: <Empty />,
        }}
        pagination={false}
      />
      <ThresholdModal
        open={visible}
        data={currentItem.JsonNumThreshold}
        onClose={() => setVisible(false)}
      />
      <ErrorHandleModal
        open={errVisible}
        userList={userList}
        onCancel={() => setErrVisible(false)}
        onOk={handleError}
      />
    </div>
  );
}
