import { DatePicker, Form, Input, Modal, Select } from 'antd';

export default function ErrorHandleModal(props) {
  const { visible, onCancel, onOk, userList } = props;
  const [form] = Form.useForm();
  const status = form.getFieldValue('Status');
  const handleOk = () => {
    form.validateFields((error, values) => {
      if (error) return;
      onOk({
        ...values,
        PlanTime: values?.PlanTime?.format('YYYY-MM-DD HH:mm:ss'),
      });
    });
  };

  return (
    <Modal
      title="异常处理"
      open={visible}
      onCancel={onCancel}
      onOk={handleOk}
      destroyOnClose
    >
      <Form labelCol={{ span: 7 }} wrapperCol={{ span: 16 }}>
        <Form.Item label="异常处理备注" name="ExceptionHandling">
          <Input.TextArea />
        </Form.Item>
        <Form.Item
          label="审核状态"
          name="Status"
          rules={[{ required: true, message: '请选择验收状态' }]}
        >
          <Select style={{ width: '100%' }} placeholder="请选择验收状态">
            <Select.Option value={1}>已派遣</Select.Option>
            <Select.Option value={2}>已通过</Select.Option>
          </Select>
        </Form.Item>
        <Form.Item
          label="维修人"
          name="RepairMan"
          rules={[{ required: true, message: '请选择维修人' }]}
        >
          <Select
            showSearch
            placeholder="请选择维修人"
            filterOption={(input, option) =>
              option.props.children.indexOf(input) >= 0
            }
            style={{ width: '100%' }}
          >
            {userList?.map((item) => (
              <Select.Option key={item.ID}>{item.CName}</Select.Option>
            ))}
          </Select>
        </Form.Item>
        {status == 1 && (
          <>
            <Form.Item
              label="难度级别"
              name="DifficultyLevel"
              rules={[{ required: true, message: '请选择难度级别' }]}
            >
              <Select placeholder="请选择难度级别" style={{ width: '100%' }}>
                <Select.Option value={0}>大修</Select.Option>
                <Select.Option value={1}>项目维修</Select.Option>
                <Select.Option value={2}>小修</Select.Option>
              </Select>
            </Form.Item>
            <Form.Item
              label="维修方式"
              name="RepairType"
              rules={[{ required: true, message: '请选择维修方式' }]}
            >
              <Select placeholder="请选择维修方式" style={{ width: '100%' }}>
                <Select.Option value={0}>自维</Select.Option>
                <Select.Option value={1}>外委</Select.Option>
              </Select>
            </Form.Item>
            <Form.Item
              label="计划完成日期"
              name="PlanTime"
              rules={[{ required: true, message: '请选择计划完成日期' }]}
            >
              <DatePicker inputReadOnly />
            </Form.Item>
          </>
        )}
      </Form>
    </Modal>
  );
}
