import TabsContent from '@/components/TabsContent';
import { useEffect, useMemo, useState } from 'react';
import styles from '../PatrolReportDetail.less';
import DeviceTable from './DeviceTable';
import WarningTable from './WarningTable';

export default function ReportCom(props) {
  const {
    sendMessageToUnity,
    select,
    allData,
    userList,
    type,
    title,
    data,
    statusCheck,
    changeStatus,
    mandate
  } = props;
  const [activeKey, setActiveKey] = useState('1');
  const handleTabsChange = (activeKey) => {
    setActiveKey(activeKey);
  };

  const { warningTableData, errorTableData, normalData } = useMemo(() => {
    let data = { warningTableData: [], errorTableData: [], normalData: [] };
    allData?.forEach((item) => {
      if (item.Status == 1 && statusCheck.includes(1)) {
        data.errorTableData.push(item);
      } else if (item.Status == 2 && statusCheck.includes(2)) {
        data.warningTableData.push(item);
      } else if (statusCheck.includes(0)) {
        data.normalData.push(item);
      }
    });
    return data;
  }, [statusCheck, allData]);

  const items = useMemo(() => {
    let items = [];
    let showAllTabs = statusCheck.length == 3;
    if (showAllTabs || errorTableData.length > 0) {
      items.push({
        key: '1',
        label: `异常(${errorTableData.length || 0})`,
        children: <div></div>,
      });
    }
    if (showAllTabs || warningTableData.length > 0) {
      items.push({
        key: '2',
        label: `警告(${warningTableData.length || 0})`,
        children: <div></div>,
      });
    }
    if (showAllTabs || normalData.length > 0) {
      items.push({
        key: '0',
        label: `正常(${normalData.length || 0})`,
        children: <div></div>,
      });
    }
    return items;
  }, [statusCheck, allData]);

  useEffect(() => {
    if (items.length == 0) {
      changeStatus(0);
    } else {
      setActiveKey(items[0].key);
      changeStatus(1);
    }
  }, [items]);

  if (items.length == 0) return null;

  return (
    <div className={styles.detailCard}>
      <div className={styles.tableTop}>
        {title}
        <TabsContent
          active={activeKey}
          onChange={handleTabsChange}
          small={true}
          items={items}
        ></TabsContent>
      </div>

      {activeKey == '1' && (
        <WarningTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={errorTableData}
          key={type}
          data={data}
          type={type}
          mandate={mandate}
          userList={userList}
        />
      )}
      {activeKey == '2' && (
        <WarningTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={warningTableData}
          key={type}
          data={data}
          type={type}
          mandate={mandate}
          userList={userList}
        />
      )}
      {activeKey == '0' && (
        <DeviceTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={allData}
          data={data}
          key={type}
          type={type}
          mandate={mandate}
          userList={userList}
        />
      )}
    </div>
  );
}
