import TabsContent from '@/components/TabsContent';
import ThresholdDetail from '@/components/ThresholdDetail';
import { Popover, Table } from 'antd';
import dayjs from 'dayjs';
import { useEffect, useMemo, useState } from 'react';
import styles from '../PatrolReportDetail.less';
import Empty from './Empty';

export default function WaterInCom(props) {
  const {
    sendMessageToUnity,
    select,
    allData = [],
    title,
    statusCheck,
    changeStatus,
  } = props;
  const [activeKey, setActiveKey] = useState('1');

  const handleTabsChange = (key) => {
    setActiveKey(key);
  };

  const { errorTableData, normalData } = useMemo(() => {
    let data = { errorTableData: [], normalData: [] };
    allData?.forEach((item) => {
      if (item.status == 1 && statusCheck.includes(1)) {
        data.errorTableData.push(item);
      } else if (item.status == 0 && statusCheck.includes(0)) {
        data.normalData.push(item);
      }
    });
    return data;
  }, [statusCheck, allData]);

  const items = useMemo(() => {
    let items = [];
    let showAllTabs = statusCheck.length == 3;
    if (showAllTabs || errorTableData.length > 0) {
      items.push({
        key: '1',
        label: `异常(${errorTableData.length || 0})`,
        children: <div></div>,
      });
    }
    if (showAllTabs || normalData.length > 0) {
      items.push({
        key: '0',
        label: `正常(${normalData.length || 0})`,
        children: <div></div>,
      });
    }
    return items;
  }, [statusCheck, allData]);

  useEffect(() => {
    if (items.length == 0) {
      changeStatus(0);
    } else {
      setActiveKey(items[0].key);
      changeStatus(1);
    }
  }, [items]);
  const content = (
    <div className={styles.popoverContent}>
      <p>进出水实际流量=超滤总进水流量-反洗水池的补水流量-反渗透总进水流量</p>
      <p>差值：进出水实际流量与流量计流量的差值</p>
    </div>
  );
  if (items.length == 0) return null;
  return (
    <div className={styles.detailCard}>
      <div className={styles.tableTop}>
        <div className={styles.tipTitle}>
          进出水流量校验
          <Popover content={content}>
            <i></i>
          </Popover>
        </div>
        <TabsContent
          active={activeKey}
          onChange={handleTabsChange}
          small
          items={items}
        ></TabsContent>
      </div>
      {activeKey === '1' && (
        <WaterInTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={errorTableData}
        />
      )}
      {activeKey === '0' && (
        <WaterInTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={normalData}
        />
      )}
    </div>
  );
}
function WaterInTable(props) {
  const { items } = props;
  const columns = [
    {
      title: '设备名称',
      width: '20%',
      dataIndex: 'item_alias',
    },
    {
      title: '差值',
      // width: '15%',
      dataIndex: 'current_val',
    },
    {
      title: '时间',
      // width: '15%',
      dataIndex: 'create_time',
      render: (text) => {
        if (text) {
          return dayjs(text).format('HH:mm:ss');
        }
        return '-';
      },
    },
    {
      title: '设定值范围',
      width: '30%',
      render: (record) => (
        <ThresholdDetail
          current={record.current_val || 0}
          data={{
            JsonNumThreshold: {
              exception: [
                { ThresholdValue: record?.thresholds, ThresholdType: 1 },
              ],
            },
            Type: 2,
          }}
        />
      ),
    },
    {
      title: '状态',
      dataIndex: 'status',
      width: '1.25rem',
      render: (status) => {
        switch (status) {
          case -1:
          case 0:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#12CEB3' }}
                />
                正常
              </div>
            );
          case 1:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FF8600' }}
                />
                异常
              </div>
            );
          case 2:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FFE26D' }}
                />
                警告
              </div>
            );
          default:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FF8600' }}
                />
                异常
              </div>
            );
        }
      },
    },
  ];

  return (
    <Table
      columns={columns}
      dataSource={items}
      rowKey="device_code"
      locale={{
        emptyText: <Empty />,
      }}
      pagination={false}
    />
  );
}
