import TabsContent from '@/components/TabsContent';
import { Table } from 'antd';
import dayjs from 'dayjs';
import { useEffect, useMemo, useState } from 'react';
import Empty from './Empty';
import styles from '../PatrolReportDetail.less';

function WaterQualityTable(props) {
  const { items } = props;
  const columns = [
    {
      title: '设备名称',
      width: '20%',
      dataIndex: 'item_alias',
    },
    {
      title: '时间范围',
      key: 'dataRange',
      width: '1.5rem',
      render: (record) => {
        if (record.query_start && record.query_end) {
          return (
            <>
              {dayjs(record.query_start).format('HH:mm:ss')}
              <br />
              {dayjs(record.query_end).format('HH:mm:ss')}
            </>
          );
        }
        return '-';
      },
    },
    {
      title: (
        <>
          仪表
          <br />
          最小数
        </>
      ),
      width: '1.25rem',
      dataIndex: 'data_min',
    },
    {
      title: (
        <>
          仪表
          <br />
          最大数
        </>
      ),
      width: '1.25rem',
      dataIndex: 'data_max',
    },
    {
      title: '可能原因',
      dataIndex: 'content',
    },
    {
      title: '状态',
      dataIndex: 'status',
      width: '1.25rem',
      render: (status) => {
        switch (status) {
          case -1:
          case 0:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#12CEB3' }}
                />
                正常
              </div>
            );
          case 1:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FF8600' }}
                />
                异常
              </div>
            );
          case 2:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FFE26D' }}
                />
                警告
              </div>
            );
          default:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FF8600' }}
                />
                异常
              </div>
            );
        }
      },
    },
  ];

  return (
    <Table
      columns={columns}
      dataSource={items}
      rowKey="device_code"
      locale={{
        emptyText: <Empty />,
      }}
      pagination={false}
    />
  );
}

export default function WaterQualityCom(props) {
  const {
    sendMessageToUnity,
    select,
    allData = [],
    title,
    statusCheck,
    changeStatus,
  } = props;
  const [activeKey, setActiveKey] = useState('1');

  const handleTabsChange = (key) => {
    setActiveKey(key);
  };

  const { errorTableData, normalData } = useMemo(() => {
    let data = { errorTableData: [], normalData: [] };
    allData?.forEach((item) => {
      if (item.status == 1 && statusCheck.includes(1)) {
        data.errorTableData.push(item);
      } else if (item.status == 0 && statusCheck.includes(0)) {
        data.normalData.push(item);
      }
    });
    return data;
  }, [statusCheck, allData]);

  const items = useMemo(() => {
    let items = [];
    let showAllTabs = statusCheck.length == 3;
    if (showAllTabs || errorTableData.length > 0) {
      items.push({
        key: '1',
        label: `异常(${errorTableData.length || 0})`,
        children: <div></div>,
      });
    }
    if (showAllTabs || normalData.length > 0) {
      items.push({
        key: '0',
        label: `正常(${normalData.length || 0})`,
        children: <div></div>,
      });
    }
    return items;
  }, [statusCheck, allData]);

  useEffect(() => {
    if (items.length == 0) {
      changeStatus(0);
    } else {
      setActiveKey(items[0].key);
      changeStatus(1);
    }
  }, [items]);

  if (items.length == 0) return null;

  return (
    <div className={styles.detailCard}>
      <div className={styles.tableTop}>
        {title}
        <TabsContent
          active={activeKey}
          onChange={handleTabsChange}
          small
          items={items}
        ></TabsContent>
      </div>
      {activeKey === '1' && (
        <WaterQualityTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={errorTableData}
        />
      )}
      {activeKey === '0' && (
        <WaterQualityTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={normalData}
        />
      )}
    </div>
  );
}
